@@ -4,8 +4,11 @@ import networkx as nx
 import matplotlib.pyplot as plt
 from pyvis.physics import Physics
 from pyvis.network import Network
-import time
+import time,re,spacy
 from basemodes.text_edges import text2edges
+nlp = spacy.load('en_core_web_lg')
+nlp.add_pipe('coreferee')
+
 
 def avnn(comments_en,by_review = False,other_edges = True,verbose_text = False,only_otherNouns = False, only_opiAV = True, nncompound = True):
 
